@@ -11,7 +11,7 @@ from collections import deque
 from datetime import datetime
 
 import attrs
-from attrs import define, field
+from attrs import define, field, asdict
 import canvasapi
 import requests
 import logging
@@ -146,7 +146,7 @@ class Profile:
 
 
 # noinspection PyCallingNonCallable,PyRedeclaration,PyTypeChecker
-AnswerOptions = dict[str, int]  # answer_text, answer_weigth
+# AnswerOptions = dict[str, int]  # answer_text, answer_weigth
 @define
 class Answer:
     """canvas answer see for a complete list of (valid) fields
@@ -156,9 +156,10 @@ class Answer:
     answer_html: str
     answer_weight: int
 
+
 @define
 class QuestionDTO:
-    answers: list[AnswerOptions]
+    answers: list[Answer]
     question_name: str = ""
     question_type: str = 'multiple_choice_question'  # another option is 'essay question'
     question_text: str = ''
@@ -193,7 +194,7 @@ class CourseMetadata:
     # avr_len_assignments: int
 
 
-# noinspection PyTypeChecker,PyUnresolvedReferences
+# noinspection PyTypeChecker,PyUnresolvedReferences,PyCallingNonCallable
 class CanvasRobot(object):
     db: callable
     from collections import deque
@@ -965,7 +966,8 @@ class CanvasRobot(object):
     def get_courses_from_database(self,
                                   skip_courses_without_students=False,
                                   qry=None,
-                                  orderby=None):
+                                  orderby=None,
+                                  fields=None):
         db = self.db
         if skip_courses_without_students:
             cur_qry = (db.course.nr_students>0)
@@ -974,6 +976,8 @@ class CanvasRobot(object):
 
         if qry:
             cur_qry = cur_qry & qry
+
+        fields = fields or db.course.ALL
         orderby=orderby or db.course.course_code
         records = db(cur_qry).select(db.course.ALL,
                                      orderby=orderby)
@@ -1459,14 +1463,18 @@ class CanvasRobot(object):
     def create_quizzes_from_data(self,
                                  course_id: int,
                                  question_format="Vraag {}.",
-                                 data=None
+                                 data=None,
+                                 gui_root=None,
+                                 gui_queue=None
                                  ):
         """
         :param course_id: Canvas course_id: the quizzes are added to this course
         :param question_format: used to create the question name.
-        They will be numbered. Should contain '{}' is placehiolder
+        They will be numbered. Should contain '{}' as  placeholder
         starting with 1
         :param data: the quizdata
+        :param gui_root: used in combination with GUI (tkinter)
+        :param gui_queue: used in combination with GUI
         :return: stats:Stats
         """
         if '{}' not in question_format:
@@ -1475,21 +1483,32 @@ class CanvasRobot(object):
             ValueError(msg)
 
         stats = Stats()
-        for quiz_name, questions in track(data):
+
+        total_questions = 0
+        for _, questions in data:
+            total_questions+=len(questions)
+
+        for quiz_name, questions in track(data): # for non-gui progress
 
             quiz_id = self.create_quiz(course_id=course_id,
                                        title=quiz_name,
                                        quiz_type="practice_quiz")
             stats.quiz_ids.append(quiz_id)
-            for index, (question_text, answers) in enumerate(questions):
-                answers_asdict = [asdict(answer) for answer in answers]
-                question_dto = QuestionDTO(question_name=question_format.format(index + 1),
+            for index, (question_text, answers) in enumerate(questions, start=1):
+                # answers_asdict = [asdict(answer) for answer in answers]
+                question_dto = QuestionDTO(question_name=question_format.format(index),
                                            question_text=question_text,
-                                           answers=answers_asdict)
+                                           answers=answers)
                 question_id = self.create_question(course_id=course_id,
                                                    quiz_id=quiz_id,
                                                    question_dto=question_dto)
                 stats.question_ids.append(question_id)
+            if gui_root:
+                gui_queue.put(index/total_questions)
+                gui_root.event_generate('<<CreateQuizzes:Progress>>')
+
+        if gui_root:
+            gui_root.event_generate('<<CreateQuizzes:Done>>')
 
         return stats
 
