@@ -160,6 +160,7 @@ class LocalDAL(DAL):
                           Field('teachers', 'list:string'),  # as usernames
                           Field('teachers_names', 'list:string'),
                           Field('status', 'integer'),
+                          Field('nr_students', 'integer'),
                           Field('nr_modules', 'integer'),
                           Field('nr_module_items', 'integer'),
                           Field('nr_pages', 'integer'),
@@ -172,6 +173,7 @@ class LocalDAL(DAL):
                           Field('examinations_summary', 'string'),
                           Field('examinations_ok', 'boolean', default=False),
                           Field('examinations_findings', 'string'),
+                          Field('examinations_details_osiris', 'string'),
                           singular='LMS course',
                           plural='LMS courses',
                           format='%(name)s[%(teacher_names)s]')
@@ -184,7 +186,9 @@ class LocalDAL(DAL):
                                                              self.course._format)),
                           Field('course_name', 'string'), # a bit redundant
                           Field('name', 'string'),
-                          Field('candidate', 'boolean', default=True),
+                          Field('candidate', 'boolean',
+                                label="Only Examination when False",
+                                default=True),
                           format='%(name)s',
                           singular='Examination name',
                           plural='Examination names')
